SumOfSquares.py
---------------

Sum of squares optimization built on top of
[picos](https://picos-api.gitlab.io/picos/). Easy access to pseudoexpectation
operators for both formulating problems and extracting solutions via rounding
algorithms.

[Examples](https://sums-of-squares.github.io/sos/index.html#python)

(Detailed documentation coming soon)
